@@ -1,6 +1,6 @@
 /*
   QtCurve KWin window decoration
-  Copyright (C) 2007 - 2010 Craig Drummond <craig.p.drummond@googlemail.com>
+  Copyright (C) 2007 - 2010 Craig Drummond <craig.p.drummond@gmail.com>
 
   based on the window decoration "Plastik":
   Copyright (C) 2003-2005 Sandro Giessl <sandro@giessl.com>
@@ -34,7 +34,7 @@
 #include <QTimer>
 #include "qtcurveclient.h"
 #include "common.h"
-
+#include <stdio.h>
 namespace KWinQtCurve
 {
 
@@ -44,12 +44,13 @@ QtCurveButton::QtCurveButton(ButtonType type, QtCurveClient *parent)
                itsIconType(NumButtonIcons),
                itsHover(false)
 {
-    setAttribute(Qt::WA_PaintOnScreen, false);
+//     setAttribute(Qt::WA_PaintOnScreen, false);
     setAttribute(Qt::WA_NoSystemBackground, true);
     setAutoFillBackground(false);
-    setFocusPolicy(Qt::NoFocus);
-    setAttribute(Qt::WA_OpaquePaintEvent, false);
-    setAttribute(Qt::WA_Hover, true);
+//     setFocusPolicy(Qt::NoFocus);
+//     setAttribute(Qt::WA_OpaquePaintEvent, false);
+//     setAttribute(Qt::WA_Hover, true);
+    setCursor(Qt::ArrowCursor); 
     reset(DecorationReset);
 }
 
@@ -102,25 +103,26 @@ void QtCurveButton::reset(unsigned long changed)
 
 void QtCurveButton::enterEvent(QEvent *e)
 {
-    QAbstractButton::enterEvent(e);
-
     itsHover = true;
-    repaint();
+    KCommonDecorationButton::enterEvent(e);
+    update();
+    // Hacky NVIDIA fix - sometimes mouseover state gets 'stuck' - but only for some windows!!!
+    QTimer::singleShot(50, this, SLOT(update()));
 }
 
 void QtCurveButton::leaveEvent(QEvent *e)
 {
-    QAbstractButton::leaveEvent(e);
-
     itsHover = false;
-    repaint();
+    KCommonDecorationButton::leaveEvent(e);
+    update();
+    // Hacky NVIDIA fix - sometimes mouseover state gets 'stuck' - but only for some windows!!!
+    QTimer::singleShot(50, this, SLOT(update()));
 }
 
 void QtCurveButton::paintEvent(QPaintEvent *ev)
 {
     QPainter p(this);
     p.setClipRect(rect().intersected(ev->rect()));
-    p.setRenderHints(QPainter::Antialiasing);
     drawButton(&p);
 }
 
@@ -165,54 +167,54 @@ void QtCurveButton::drawButton(QPainter *painter)
 //     if(CloseButton==type())
 //         buttonColor=midColor(QColor(180,64,32), buttonColor);
 
-    if(flags&TITLEBAR_BUTTON_COLOR)
-        switch(type())
-        {
-            case HelpButton:
-                versionHack=TBAR_VERSION_HACK+TITLEBAR_HELP;
-                break;
-            case MaxButton:
-                versionHack=TBAR_VERSION_HACK+TITLEBAR_MAX;
-                break;
-            case MinButton:
-                versionHack=TBAR_VERSION_HACK+TITLEBAR_MIN;
-                break;
+    switch(type())
+    {
+        case HelpButton:
+            versionHack=TBAR_VERSION_HACK+TITLEBAR_HELP;
+            break;
+        case MaxButton:
+            versionHack=TBAR_VERSION_HACK+TITLEBAR_MAX;
+            break;
+        case MinButton:
+            versionHack=TBAR_VERSION_HACK+TITLEBAR_MIN;
+            break;
 #if KDE_IS_VERSION(4, 3, 85)
-            case ItemCloseButton:
+        case ItemCloseButton:
 #endif
-            case CloseButton:
-                versionHack=TBAR_VERSION_HACK+TITLEBAR_CLOSE;
-                break;
-            case MenuButton:
-                versionHack=TBAR_VERSION_HACK+TITLEBAR_MENU;
-                break;
-            case OnAllDesktopsButton:
-                versionHack=TBAR_VERSION_HACK+TITLEBAR_ALL_DESKTOPS;
-                break;
-            case AboveButton:
-                versionHack=TBAR_VERSION_HACK+TITLEBAR_KEEP_ABOVE;
-                break;
-            case BelowButton:
-                versionHack=TBAR_VERSION_HACK+TITLEBAR_KEEP_BELOW;
-                break;
-            case ShadeButton:
-                versionHack=TBAR_VERSION_HACK+TITLEBAR_SHADE;
-            default:
-                break;
-        }
+        case CloseButton:
+            versionHack=TBAR_VERSION_HACK+TITLEBAR_CLOSE;
+            break;
+        case MenuButton:
+            versionHack=TBAR_VERSION_HACK+TITLEBAR_MENU;
+            break;
+        case OnAllDesktopsButton:
+            versionHack=TBAR_VERSION_HACK+TITLEBAR_ALL_DESKTOPS;
+            break;
+        case AboveButton:
+            versionHack=TBAR_VERSION_HACK+TITLEBAR_KEEP_ABOVE;
+            break;
+        case BelowButton:
+            versionHack=TBAR_VERSION_HACK+TITLEBAR_KEEP_BELOW;
+            break;
+        case ShadeButton:
+            versionHack=TBAR_VERSION_HACK+TITLEBAR_SHADE;
+        default:
+            break;
+    }
 
-    if (drawFrame && (!(flags&TITLEBAR_BUTTON_ROUND) || MenuButton!=type() || !iconForMenu))
+    if (drawFrame && (/*!(flags&TITLEBAR_BUTTON_ROUND) || */MenuButton!=type() || !iconForMenu))
     {
         QStyleOption opt;
         int          offset=flags&TITLEBAR_BUTTON_ROUND && !itsClient->isToolWindow() ? 1 : 0;
 
-        if(flags&TITLEBAR_BUTTON_SUNKEN_BACKGROUND && flags&TITLEBAR_BUTTON_ROUND)
+        if(flags&TITLEBAR_BUTTON_SUNKEN_BACKGROUND) // && flags&TITLEBAR_BUTTON_ROUND)
             offset++;
         opt.init(this);
         opt.rect=QRect(offset, offset, width()-(2*offset), height()-(2*offset));
         opt.state|=(isDown() ? QStyle::State_Sunken : QStyle::State_Raised) |
                    (active ? QStyle::State_Active : QStyle::State_None) |
                    (itsHover ? QStyle::State_MouseOver : QStyle::State_None)|QStyle::State_Horizontal|QtC_StateKWin;
+        opt.state&=~QStyle::State_HasFocus;
         if(!isEnabled())
             opt.palette.setColor(QPalette::Button, buttonColor);
         else
@@ -265,13 +267,13 @@ void QtCurveButton::drawButton(QPainter *painter)
                 QStyleOption opt;
 
                 opt.init(this);
-                opt.version=versionHack;
                 if(userDefined)
                 {
                     versionHack+=NUM_TITLEBAR_BUTTONS;
                     if(!active)
                         versionHack+=NUM_TITLEBAR_BUTTONS;
                 }
+                opt.version=versionHack;
                 col=QColor(QRgb(Handler()->wStyle()->pixelMetric((QStyle::PixelMetric)QtC_TitleBarIconColor, &opt, 0L)));
                 customCol=true;
             }
@@ -291,17 +293,22 @@ void QtCurveButton::drawButton(QPainter *painter)
             bP.drawPixmap(EFFECT_SHADOW==effect ? dX+1 : dX, dY+1, icon);
         }
 
-        if( (CloseButton==type()
+        if(itsHover && !sunken && !(flags&TITLEBAR_BUTTON_COLOR) && !customCol)
+        {
+            if(CloseButton==type()
 #if KDE_IS_VERSION(4, 3, 85)
-              || isTabClose
+                || isTabClose
 #endif
-             ) && itsHover && !(flags&TITLEBAR_BUTTON_COLOR) && !customCol)
-            col=CLOSE_COLOR;
+                )
+                col=CLOSE_COLOR;
+            else if(flags&TITLEBAR_BUTTON_USE_HOVER_COLOR)
+                col=Handler()->hoverCol(active);
+        }
 
         if(faded)
             col.setAlphaF(HOVER_BUTTON_ALPHA(col));
         else // If dont set an alpha level here, then (at least on intel) the background colour is used!
-            col.setAlphaF(0.99);
+            col.setAlpha(254);
 
         bP.setPen(col);
         bP.drawPixmap(dX, dY, icon);
@@ -316,7 +323,7 @@ QBitmap IconEngine::icon(ButtonIcon icon, int size, QStyle *style)
     if (size%2 == 0)
         --size;
 
-    QBitmap bitmap(size,size);
+    QBitmap bitmap(size, size);
     bitmap.fill(Qt::color0);
     QPainter p(&bitmap);
 
